"use strict";
//
// Copyright 2023 Signal Messenger, LLC.
// SPDX-License-Identifier: AGPL-3.0-only
//
Object.defineProperty(exports, "__esModule", { value: true });
exports.Net = exports.Environment = void 0;
const Native = require("../Native");
const Address_1 = require("./Address");
// This must match the libsignal-bridge Rust enum of the same name.
var Environment;
(function (Environment) {
    Environment[Environment["Staging"] = 0] = "Staging";
    Environment[Environment["Production"] = 1] = "Production";
})(Environment = exports.Environment || (exports.Environment = {}));
class Net {
    constructor(env) {
        this._asyncContext = Native.TokioAsyncContext_new();
        this._connectionManager = Native.ConnectionManager_new(env);
    }
    async cdsiLookup({ username, password }, { e164s, acisAndAccessKeys, timeout, returnAcisWithoutUaks, }) {
        const request = { _nativeHandle: Native.LookupRequest_new() };
        e164s.forEach((e164) => {
            Native.LookupRequest_addE164(request, e164);
        });
        acisAndAccessKeys.forEach(({ aci: aciStr, accessKey: accessKeyStr }) => {
            Native.LookupRequest_addAciAndAccessKey(request, Address_1.Aci.parseFromServiceIdString(aciStr).getServiceIdFixedWidthBinary(), Buffer.from(accessKeyStr, 'base64'));
        });
        Native.LookupRequest_setReturnAcisWithoutUaks(request, returnAcisWithoutUaks);
        const lookup = await Native.CdsiLookup_new({ _nativeHandle: this._asyncContext }, { _nativeHandle: this._connectionManager }, username, password, request, timeout);
        return await Native.CdsiLookup_complete({ _nativeHandle: this._asyncContext }, { _nativeHandle: lookup });
    }
}
exports.Net = Net;
//# sourceMappingURL=net.js.map